@@ -6,7 +6,7 @@ import attr
 
 @attr.dataclass(frozen=True, slots=True)
 class PangkatGolongan:
-    pangkat_golongan_id: str
+    pangkat_golongan_id: int
     kode: str
     nama: str
     create_date: datetime
